pub enum EigenError {
    InvalidPreTrustScores,
    PeerNotFound,
    GlobalTrustCalculationFailed,
    InvalidManagerKeys,
    InvalidManagerPerPeer,
    FailedToFindManagers,
}
The module wide error variants.

Variants

InvalidPreTrustScores

Invalid pre trust scores passed

PeerNotFound

Peer not found in the network or peer cache

GlobalTrustCalculationFailed

Managers couldn’t agree on the global trust score for a peer

InvalidManagerKeys

Invalid keys for the manager generated

InvalidManagerPerPeer

Invalid number of managers per peer

FailedToFindManagers

Failed to find managers for a peer