Node

Struct Node 

pub struct Node<C: NodeConfig> { /* private fields */ }
The Node struct.

Implementations

Source

impl<C: NodeConfig> Node<C>

pub fn new( local_key: Keypair, local_address: Multiaddr, bootstrap_nodes: Vec<(PeerId, Multiaddr, f64)>, ) -> Result<Self, EigenError>

Create a new node, given the local keypair, local address, and bootstrap nodes.

pub fn get_peer(&self) -> &Peer

Get the peer struct.

pub fn get_peer_mut(&mut self) -> &mut Peer

Get the mutable peer struct.

pub fn get_swarm_mut(&mut self) -> &mut Swarm<RequestResponse<EigenTrustCodec>>

Get the mutable swarm.

pub fn handle_req_res_events( &mut self, event: RequestResponseEvent<Request, Response>, )

Method for handling the request/response events.

pub fn handle_swarm_events( &mut self, event: SwarmEvent<RequestResponseEvent<Request, Response>, ConnectionHandlerUpgrErr<IoError>>, )

A method for handling the swarm events.

pub fn dial_neighbor(&mut self, addr: Multiaddr)

Dial the neighbor directly.

pub fn dial_bootstrap_nodes(&mut self)

Dial pre-configured bootstrap nodes.

pub fn send_epoch_requests(&mut self, epoch: Epoch)

Send the request for an opinion to all neighbors, in the passed epoch.

pub async fn main_loop( self, interval_limit: Option<u32>, ) -> Result<(), EigenError>

Start the main loop of the program. This function has two main tasks:

  • To start an interval timer for sending the request for opinions.
  • To handle the swarm + request/response events. The amount of intervals/epochs is determined by the interval_limit parameter.