Peer

Struct Peer 

pub struct Peer { /* private fields */ }
The peer struct.

Implementations

Source

impl Peer

pub fn new( num_neighbors: usize, pre_trust_score: f64, pre_trust_weight: f64, ) -> Self

Creates a new peer.

pub fn add_neighbor(&mut self, peer_id: PeerId) -> Result<(), EigenError>

Adds a neighbor in the first available spot.

pub fn remove_neighbor(&mut self, peer_id: PeerId)

Removes a neighbor, if found.

pub fn neighbors(&self) -> Vec<PeerId>

Returns the neighbors of the peer.

pub fn set_score(&mut self, peer_id: PeerId, score: u32)

Set the local score towards a neighbor.

pub fn calculate_global_trust_score(&self, epoch: Epoch) -> f64

Calculate the global trust score of the peer in the specified epoch. We do this by taking the sum of neighbor’s opinions and weighting it by the pre trust weight. Then we are adding it with the weighted pre-trust score.

pub fn calculate_local_opinions(&mut self, k: Epoch)

Calculate the local trust score toward all neighbors in the specified epoch.

pub fn get_sum_of_scores(&self) -> u32

Returns sum of local scores.

pub fn get_normalized_score(&self, score: u32) -> f64

Returns the normalized score.

pub fn get_local_opinion(&self, key: &(PeerId, Epoch)) -> Opinion

Returns the local score towards a neighbor in a specified epoch.

pub fn cache_local_opinion(&mut self, key: (PeerId, Epoch), opinion: Opinion)

Caches the local opinion towards a peer in a specified epoch.

pub fn get_neighbor_opinion(&self, key: &(PeerId, Epoch)) -> Opinion

Returns the neighbor’s opinion towards us in a specified epoch.

pub fn cache_neighbor_opinion(&mut self, key: (PeerId, Epoch), opinion: Opinion)

Caches the neighbor opinion towards us in specified epoch.