pub struct Epoch(pub u64);Expand description
Epoch struct, which is a wrapper around epoch number and timestamp.
Tuple Fields
0: u64Implementations
Sourceimpl Epoch
impl Epoch
Sourcepub fn to_be_bytes(self) -> [u8; 8]
pub fn to_be_bytes(self) -> [u8; 8]
Returns epoch number as bytes.
Sourcepub fn current_epoch(interval: u64) -> Result<Self, EigenError>
pub fn current_epoch(interval: u64) -> Result<Self, EigenError>
Calculates the current epoch number based on the interval duration.
Sourcepub fn secs_until_next_epoch(interval: u64) -> Result<u64, EigenError>
pub fn secs_until_next_epoch(interval: u64) -> Result<u64, EigenError>
Calculates the seconds until the next epoch based on the interval duration.
Sourcepub fn current_timestamp() -> Result<u64, EigenError>
pub fn current_timestamp() -> Result<u64, EigenError>
Calculates the current timestamp. The difference between UNIX timestamp start and now.